@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.123_01';
+our $VERSION = '0.124_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1683,12 +1683,12 @@ sub _set_operational_status {
 #
 # Generated by Astro::SpaceTrack
 # $ tools/all_iridium_classic -iridium -indent=0
-# on Wed Jul 24 16:04:51 2019 GMT
+# on Fri Dec 20 14:19:31 2019 GMT
 #
 # The following static method is UNSUPPORTED, and exists solely for the
 # benefit of xt/author/iridium_status.t. It may be modified or revoked
 # at any time.
-sub __iridium_status_as_of { return( qw{ 47 30 22 23 6 2019 } ) }
+sub __iridium_status_as_of { return( qw{ 32 42 18 19 11 2019 } ) }
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1786,13 +1786,13 @@ __PACKAGE__->status( add => 27373, iridium => 'D', 'Iridium 90', 'Decayed 2019-0
 __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-04-18' );
 __PACKAGE__->status( add => 27375, iridium => 'D', 'Iridium 95', 'Decayed 2019-03-25' );
 __PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'Tumbling' );
-__PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
+__PACKAGE__->status( add => 27450, iridium => '-', 'Iridium 97', 'Tumbling' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
 # Operational [+]: 0
-#       Spare [S]: 1
-#    Tumbling [-]: 32
+#       Spare [S]: 0
+#    Tumbling [-]: 33
 #     Decayed [D]: 64
 
 1;
